aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorThiago Farina <tfransosi@gmail.com>2010-11-06 14:09:44 -0200
committerLinus Torvalds <torvalds@linux-foundation.org>2010-11-06 09:21:41 -0700
commit6ceea8ba9b06c89cd0fd8342f9248d5ca2ff7563 (patch)
tree6914d3132553b0d1ccc36a023b91d90524ea6fe5
parentfa57a63d574dc9f3d2274cfb93e47499c8745c9e (diff)
downloaduemacs-6ceea8ba9b06c89cd0fd8342f9248d5ca2ff7563.tar.gz
uemacs: convert typedef struct VDESC to struct variable_description.
Signed-off-by: Thiago Farina <tfransosi@gmail.com> Signed-off-by: Linus Torvalds <torvalds@linux-foundation.org>
-rw-r--r--efunc.h4
-rw-r--r--estruct.h44
-rw-r--r--eval.c20
3 files changed, 32 insertions, 36 deletions
diff --git a/efunc.h b/efunc.h
index 82b37b1..0077e71 100644
--- a/efunc.h
+++ b/efunc.h
@@ -352,8 +352,8 @@ extern char *gtusr(char *vname);
extern char *gtenv(char *vname);
extern char *getkill(void);
extern int setvar(int f, int n);
-extern void findvar(char *var, VDESC *vd, int size);
-extern int svar(VDESC *var, char *value);
+extern void findvar(char *var, struct variable_description *vd, int size);
+extern int svar(struct variable_description *var, char *value);
extern char *itoa(int i);
extern int gettyp(char *token);
extern char *getval(char *token);
diff --git a/estruct.h b/estruct.h
index 3317192..75acb4a 100644
--- a/estruct.h
+++ b/estruct.h
@@ -594,35 +594,31 @@ struct name_bind {
int (*n_func)(int, int); /* function name is bound to */
};
-/* The editor holds deleted text chunks in the struct kill buffer. The
- kill buffer is logically a stream of ascii characters, however
- due to its unpredicatable size, it gets implemented as a linked
- list of chunks. (The d_ prefix is for "deleted" text, as k_
- was taken up by the keycode structure)
-*/
-
+/* The editor holds deleted text chunks in the struct kill buffer. The
+ * kill buffer is logically a stream of ascii characters, however
+ * due to its unpredicatable size, it gets implemented as a linked
+ * list of chunks. (The d_ prefix is for "deleted" text, as k_
+ * was taken up by the keycode structure).
+ */
struct kill {
- struct kill *d_next; /* link to next chunk, NULL if last */
- char d_chunk[KBLOCK]; /* deleted text */
+ struct kill *d_next; /* Link to next chunk, NULL if last. */
+ char d_chunk[KBLOCK]; /* Deleted text. */
};
-/* When emacs' command interpetor needs to get a variable's name,
- rather than it's value, it is passed back as a VDESC variable
- description structure. The v_num field is a index into the
- appropriate variable table.
-*/
-
-typedef struct VDESC {
- int v_type; /* type of variable */
- int v_num; /* ordinal pointer to variable in list */
-} VDESC;
+/* When emacs' command interpetor needs to get a variable's name,
+ * rather than it's value, it is passed back as a variable description
+ * structure. The v_num field is a index into the appropriate variable table.
+ */
+struct variable_description {
+ int v_type; /* Type of variable. */
+ int v_num; /* Ordinal pointer to variable in list. */
+};
-/* The !WHILE directive in the execution language needs to
- stack references to pending whiles. These are stored linked
- to each currently open procedure via a linked list of
- the following structure
+/* The !WHILE directive in the execution language needs to
+ * stack references to pending whiles. These are stored linked
+ * to each currently open procedure via a linked list of
+ * the following structure.
*/
-
struct while_block {
struct line *w_begin; /* ptr to !while statement */
struct line *w_end; /* ptr to the !endwhile statement */
diff --git a/eval.c b/eval.c
index 3a5999c..c56be78 100644
--- a/eval.c
+++ b/eval.c
@@ -354,7 +354,7 @@ int setvar(int f, int n)
char *sp; /* temp string pointer */
char *ep; /* ptr to end of outline */
#endif
- VDESC vd; /* variable num/type */
+ struct variable_description vd; /* variable num/type */
char var[NVSIZE + 1]; /* name of variable to fetch */
char value[NSTRING]; /* value to set variable to */
@@ -442,13 +442,13 @@ int setvar(int f, int n)
}
/*
- * find a variables type and name
+ * Find a variables type and name.
*
* char *var; name of var to get
* VDESC *vd; structure to hold type and ptr
* int size; size of var array
*/
-void findvar(char *var, VDESC *vd, int size)
+void findvar(char *var, struct variable_description *vd, int size)
{
int vnum; /* subscript in variable arrays */
int vtype; /* type to return */
@@ -501,12 +501,12 @@ fvar:
}
/*
- * set a variable
+ * Set a variable.
*
- * VDESC *var; variable to set
- * char *value; value to set to
+ * @var: variable to set.
+ * @value: value to set to.
*/
-int svar(VDESC *var, char *value)
+int svar(struct variable_description *var, char *value)
{
int vnum; /* ordinal number of var refrenced */
int vtype; /* type of variable to set */
@@ -442,13 +442,13 @@ int setvar(int f, int n)
*
- * char *var; name of var to get
- * VDESC *vd; structure to hold type and ptr
- * int size; size of var array
+ * @var: name of variable to get.
+ * @vd: structure to hold type and pointer.
+ * @size: size of variable array.
*/